
# Slot: causes


holds between two entities where the occurrence, existence, or activity of one causes the occurrence or  generation of the other

URI: [biolink:causes](https://w3id.org/biolink/vocab/causes)

## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [contributes to](contributes_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)
